@@ -311,7 +311,7 @@ def stage_app_on_host(base_dir, config, app, host, archive_filename, update_venv
         if update_venv:
             host.execute("rm", "-rf", host.path("venvs", app.venv_name))
             if app.use_python3:
-                host.execute(host.virtualenv, "-p", host.python3, host.path("venvs", app.venv_name))
+                host.execute(host.python3, "-m", "venv", host.path("venvs", app.venv_name))
             else:
                 host.execute(host.virtualenv, host.path("venvs", app.venv_name))
             host.execute(
